# pipq
Yet another pip search.
I made it unintentionally therefore the code may not be the finest. It's not. :(


It is fairly fast.
It's basically a scraper.

## Installation?
 -

## Packages used:
 * typer
 * requests
 * typing
 * rich
 * bs4

## Commands
```
pyq search <packagename> [--raw] [--space]
```
Searches for the package
```
pyq pkg <packagename>
```
Searches for a package details
```
pyq versions <packagename> [--all]
```
This one's pretty self explanantory
